package com.chinaitop.depot.customer.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import com.chinaitop.depot.customer.mapper.BusinessCustomerMapper;
import com.chinaitop.depot.customer.model.BusinessCustomer;
import com.chinaitop.depot.customer.model.BusinessCustomerExample;
import com.chinaitop.depot.customer.model.BusinessCustomerExample.Criteria;
import com.chinaitop.depot.customer.service.BusinessCustomerService;
import com.github.pagehelper.PageHelper;


@Service
public class BusinessCustomerServiceImpl implements BusinessCustomerService {
	
	@Resource
	private BusinessCustomerMapper customerMapper;
	
	@Override
	public List<BusinessCustomer> queryByExample(BusinessCustomerExample example) {
		return customerMapper.selectByExample(example);
	}

	@Override
	public BusinessCustomer findById(Integer id) {
		return customerMapper.selectByPrimaryKey(id);
	}

	@Override
	public void add(BusinessCustomer customer,  Integer orgId) {
	    customer.setIsInBlacklist(0);
	    customer.setOrgId(orgId);
		customerMapper.insert(customer);
	}

	@Override
	public void update(BusinessCustomer customer) {
		customerMapper.updateByPrimaryKey(customer);
	}

	@Override
	public void remove(Integer id) {
		customerMapper.deleteByPrimaryKey(id);
	}

	// 加入黑名单.
	@Override
    public Map<String, Object> putInBlackList(Integer id) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        returnMap.put("success", "success");
        BusinessCustomer customer = new BusinessCustomer();
        customer.setId(id);
        customer.setIsInBlacklist(1);
        customerMapper.updateByPrimaryKeySelective(customer);
        return returnMap;
    }

    // 移除黑名单.
    @Override
    public Map<String, Object> removeBlackList(Integer id) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        returnMap.put("success", "success");
        BusinessCustomer customer = new BusinessCustomer();
        customer.setId(id);
        customer.setIsInBlacklist(0);
        customerMapper.updateByPrimaryKeySelective(customer);
        return returnMap;
    }

    /**
     * 条件查询.
     */
    @Override
    public List<BusinessCustomer> list(Integer pageNum, Integer pageSize,
            BusinessCustomer customer, Integer orgId) {
        BusinessCustomerExample example = new BusinessCustomerExample();
        Criteria createCriteria = example.createCriteria();
        // 所属机构.
        createCriteria.andOrgIdEqualTo(orgId);
        // 客户名称.
        if (StringUtils.isNotBlank(customer.getName())) {
            createCriteria.andNameLike("%" + customer.getName() + "%");
        }
        // 客户类型.
        if (customer.getClassify() != null) {
            createCriteria.andClassifyEqualTo(customer.getClassify());
        }
        // 是否在黑名单
        if (customer.getIsInBlacklist() != null) {
            createCriteria.andIsInBlacklistEqualTo(customer.getIsInBlacklist());
        }
        // id倒序.
        example.setOrderByClause("id desc");
        PageHelper.startPage(pageNum, pageSize);
        return customerMapper.selectByExample(example);
    }

}
